nbconvert: Converting Jupyter Notebooks
=======================================

Description
-----------

jupyter nbconvert converts notebooks to various other formats via Jinja
templates.

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/nbconvert/

